@@ -23,8 +23,8 @@
 #ifndef __GTK_SOURCE_COMPLETION_INFO_H__
 #define __GTK_SOURCE_COMPLETION_INFO_H__
 
-#include <glib-object.h>
 #include <gtk/gtk.h>
+#include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
 
@@ -37,8 +37,6 @@ G_BEGIN_DECLS
 
 typedef struct _GtkSourceCompletionInfoPrivate GtkSourceCompletionInfoPrivate;
 
-typedef struct _GtkSourceCompletionInfo GtkSourceCompletionInfo;
-
 struct _GtkSourceCompletionInfo
 {
 	GtkWindow parent;
@@ -64,9 +62,11 @@ void		 gtk_source_completion_info_move_to_iter	(GtkSourceCompletionInfo *info,
 								 GtkTextView             *view,
 								 GtkTextIter             *iter);
 
-void		 gtk_source_completion_info_set_widget	(GtkSourceCompletionInfo *info,
+G_DEPRECATED_FOR (gtk_container_add)
+void		 gtk_source_completion_info_set_widget		(GtkSourceCompletionInfo *info,
 								 GtkWidget               *widget);
 
+G_DEPRECATED_FOR (gtk_bin_get_child)
 GtkWidget	*gtk_source_completion_info_get_widget		(GtkSourceCompletionInfo *info);
 
 G_END_DECLS
